from setuptools import setup

setup(name='simple-distributions-build-2020-hk',
      version='0.1.2',
      description='Gaussian/Binomial distributions',
      packages=['simple-distributions-build-2020-hk'],
      zip_safe=False)
